# pylint: disable=missing-function-docstring
# pylint: disable=unused-import
# pylint: disable=line-too-long

from utils.parse_sql import drop_table,insert_sql